==> cppad_2014.00.00.3.orig.tar.gz: cppad-20140000.3/doc/_cppad_ipopt_nlp_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'deprecated.xml',
'cppad_ipopt_nlp.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'license.xml'
];
var list_down1 = [
'include_deprecated.xml',
'fundeprecated.xml',
'omp_max_thread.xml',
'tracknewdel.xml',
'omp_alloc.xml',
'memory_leak.xml',
'epsilon.xml',
'test_vector.xml',
'cppad_ipopt_nlp.xml',
'old_atomic.xml'
];
var list_down0 = [
'ipopt_nlp_get_started.cpp.xml',
'ipopt_nlp_ode.xml',
'ipopt_ode_speed.cpp.xml'
];
var list_current0 = [
'cppad_ipopt_nlp.xml#Deprecated',
'cppad_ipopt_nlp.xml#Syntax',
'cppad_ipopt_nlp.xml#Purpose',
'cppad_ipopt_nlp.xml#cppad_ipopt namespace',
'cppad_ipopt_nlp.xml#ipopt_library_paths',
'cppad_ipopt_nlp.xml#fg(x)',
'cppad_ipopt_nlp.xml#fg(x).Index Vector',
'cppad_ipopt_nlp.xml#fg(x).Projection',
'cppad_ipopt_nlp.xml#fg(x).Injection',
'cppad_ipopt_nlp.xml#fg(x).Representation',
'cppad_ipopt_nlp.xml#Simple Representation',
'cppad_ipopt_nlp.xml#SizeVector',
'cppad_ipopt_nlp.xml#NumberVector',
'cppad_ipopt_nlp.xml#ADNumber',
'cppad_ipopt_nlp.xml#ADVector',
'cppad_ipopt_nlp.xml#n',
'cppad_ipopt_nlp.xml#m',
'cppad_ipopt_nlp.xml#x_i',
'cppad_ipopt_nlp.xml#x_l',
'cppad_ipopt_nlp.xml#x_u',
'cppad_ipopt_nlp.xml#g_l',
'cppad_ipopt_nlp.xml#g_u',
'cppad_ipopt_nlp.xml#fg_info',
'cppad_ipopt_nlp.xml#fg_info.fg_info.number_functions',
'cppad_ipopt_nlp.xml#fg_info.fg_info.eval_r',
'cppad_ipopt_nlp.xml#fg_info.fg_info.retape',
'cppad_ipopt_nlp.xml#fg_info.fg_info.domain_size',
'cppad_ipopt_nlp.xml#fg_info.fg_info.range_size',
'cppad_ipopt_nlp.xml#fg_info.fg_info.number_terms',
'cppad_ipopt_nlp.xml#fg_info.fg_info.index',
'cppad_ipopt_nlp.xml#solution',
'cppad_ipopt_nlp.xml#solution.status',
'cppad_ipopt_nlp.xml#solution.x',
'cppad_ipopt_nlp.xml#solution.z_l',
'cppad_ipopt_nlp.xml#solution.z_u',
'cppad_ipopt_nlp.xml#solution.g',
'cppad_ipopt_nlp.xml#solution.lambda',
'cppad_ipopt_nlp.xml#solution.obj_value',
'cppad_ipopt_nlp.xml#Example',
'cppad_ipopt_nlp.xml#Wish List'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2016.00.00.1.orig.tar.gz: cppad-20160000.1/doc/_cppad_ipopt_nlp_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'deprecated.xml',
'cppad_ipopt_nlp.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'wish_list.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'numeric_ad.xml',
'addon.xml',
'license.xml'
];
var list_down1 = [
'include_deprecated.xml',
'fundeprecated.xml',
'comparechange.xml',
'omp_max_thread.xml',
'tracknewdel.xml',
'omp_alloc.xml',
'memory_leak.xml',
'epsilon.xml',
'test_vector.xml',
'cppad_ipopt_nlp.xml',
'old_atomic.xml',
'zdouble.xml'
];
var list_down0 = [
'ipopt_nlp_get_started.cpp.xml',
'ipopt_nlp_ode.xml',
'ipopt_ode_speed.cpp.xml'
];
var list_current0 = [
'cppad_ipopt_nlp.xml#Deprecated 2012-11-28',
'cppad_ipopt_nlp.xml#Syntax',
'cppad_ipopt_nlp.xml#Purpose',
'cppad_ipopt_nlp.xml#cppad_ipopt namespace',
'cppad_ipopt_nlp.xml#ipopt_library_paths',
'cppad_ipopt_nlp.xml#fg(x)',
'cppad_ipopt_nlp.xml#fg(x).Index Vector',
'cppad_ipopt_nlp.xml#fg(x).Projection',
'cppad_ipopt_nlp.xml#fg(x).Injection',
'cppad_ipopt_nlp.xml#fg(x).Representation',
'cppad_ipopt_nlp.xml#Simple Representation',
'cppad_ipopt_nlp.xml#SizeVector',
'cppad_ipopt_nlp.xml#NumberVector',
'cppad_ipopt_nlp.xml#ADNumber',
'cppad_ipopt_nlp.xml#ADVector',
'cppad_ipopt_nlp.xml#n',
'cppad_ipopt_nlp.xml#m',
'cppad_ipopt_nlp.xml#x_i',
'cppad_ipopt_nlp.xml#x_l',
'cppad_ipopt_nlp.xml#x_u',
'cppad_ipopt_nlp.xml#g_l',
'cppad_ipopt_nlp.xml#g_u',
'cppad_ipopt_nlp.xml#fg_info',
'cppad_ipopt_nlp.xml#fg_info.fg_info.number_functions',
'cppad_ipopt_nlp.xml#fg_info.fg_info.eval_r',
'cppad_ipopt_nlp.xml#fg_info.fg_info.retape',
'cppad_ipopt_nlp.xml#fg_info.fg_info.domain_size',
'cppad_ipopt_nlp.xml#fg_info.fg_info.range_size',
'cppad_ipopt_nlp.xml#fg_info.fg_info.number_terms',
'cppad_ipopt_nlp.xml#fg_info.fg_info.index',
'cppad_ipopt_nlp.xml#solution',
'cppad_ipopt_nlp.xml#solution.status',
'cppad_ipopt_nlp.xml#solution.x',
'cppad_ipopt_nlp.xml#solution.z_l',
'cppad_ipopt_nlp.xml#solution.z_u',
'cppad_ipopt_nlp.xml#solution.g',
'cppad_ipopt_nlp.xml#solution.lambda',
'cppad_ipopt_nlp.xml#solution.obj_value',
'cppad_ipopt_nlp.xml#Example',
'cppad_ipopt_nlp.xml#Wish List'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
